#
# spec file for package stern
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           stern
Version:        1.32.0
Release:        1.1
Summary:        Multi pod and container log tailing for Kubernetes
License:        Apache-2.0
URL:            https://github.com/stern/stern
Source:         stern-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  go >= 1.23.5

%description
Stern allows you to tail multiple pods on Kubernetes and multiple containers
within the pod. Each result is color coded for quicker debugging.

The query is a regular expression so the pod name can easily be filtered and
you don't need to specify the exact id (for instance omitting the deployment
id). If a pod is deleted it gets removed from tail and if a new pod is added it
automatically gets tailed.

When a pod contains multiple containers Stern can tail all of them too without
having to do this manually for each one. Simply specify the container flag to
limit what containers to show. By default all containers are listened to.

%prep
%autosetup -p 1 -a 1

%build
go build \
   -mod=vendor \
   -buildmode=pie \
   -o bin/stern .

%install
# Install the binary.
install -D -m 0755 bin/%{name} "%{buildroot}/%{_bindir}/%{name}"

%files
%doc README.md
%license LICENSE
%{_bindir}/%{name}

%changelog
* Tue Jan 21 2025 opensuse_buildservice@ojkastl.de
- Update to version 1.32.0:
  * Update CHANGELOG for v1.32.0 (#334)
  * Fix a typo `toUTC` (#333)
  * Update dependencies for Kubernetes 1.32 (#332)
  * Add `--condition` (#276)
  * Add check for when `--no-follow` is set with `--tail=0` (#331)
  * Implement JSON pretty print (#324)
  * Fix descriptions of `extjson` and `ppextjson` (#325)
  * Allow `levelColor` template function to parse numbers (#321)
* Fri Oct 11 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.31.0:
  * Update CHANGELOG for v1.31.0 (#318)
  * Fix --verbosity flag to show missing logs (#317)
  * Update dependencies for Kubernetes 1.31 (#315)
* Fri May 24 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.30.0:
  * Update CHANGELOG for v1.30.0 (#307)
  * Add support to configure colors for pods and containers (#306)
  * Display different colors for different containers (#305)
  * Support an array value in the config file (#303)
* Thu May  2 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.29.0:
  * Update CHANGELOG for v1.29.0 (#301)
  * Add support for UNIX time with nanoseconds to template
    functions (#300)
  * Clarify that '=' cannot be omitted in --timestamps (#296)
  * Added example to README (#295)
  * Update dependencies for Kubernetes 1.30 (#293)
  * Add `--stdin` for `stdin` log parsing (#292)
* Tue Jan  9 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.28.0:
  * Update dependencies and tools (#290)
  * adding a highlight option (#289)
  * Add tail all to README.md (#288)
  * Update README.md - make text reference for pod-query match
    formatting of cli example (#286)
* Thu Nov 16 2023 kastl@b1-systems.de
- Update to version 1.27.0:
  * Update CHANGELOG for v1.27.0 (#285)
  * Add generic cli options (#283)
  * 281: Support toTimestamp template function (#282)
* Thu Sep  7 2023 kastl@b1-systems.de
- Update to version 1.26.0:
  * Update CHANGELOG for v1.26.0 (#274)
  * Fix the release workflow (#275)
  * Update dependencies and tools (#273)
  * Possibility to extract parts of a json-message. (#271)
  * Fix potential panic in stern.Run() (#267)
  * Add log level color keys and handle default (#264)
  * Fix typo in README.md (#261)
  * Integrate fmt and vet checks into golangci-lint (#260)
  * Update Github Actions dependencies (#259)
* Fri Apr 14 2023 kastl@b1-systems.de
- Update to version 1.25.0:
  * Update CHANGELOG for v1.25.0 (#258)
  * Fix the heading level in README.md (#257)
  * Update dependencies and tools (#256)
  * Allow an empty config file (#255)
  * Add support for the config file (#254)
  * Make setup-go get Go version from go.mod (#253)
* Sun Mar 12 2023 kastl@b1-systems.de
- Update to version 1.24.0:
  * Update CHANGELOG for v1.24.0 (#251)
  * Upgrade golang.org/x/net to fix a dependabot alert (#250)
  * Add a short format for timestamps (#249)
  * Bump golangci-lint to v1.51.2 (#248)
  * Add dynamic completion for --node flag (#244)
  * Add --node flag to filter on a specific node (#243)
  * allow flexible log parsing and formatting (#239)
  * Documenting how to get Bash completion in Krew mode (#240)
  * Add CI for skipped files (#241)
  * Replace actions/cache with setup-go's cache (#238)
  * Make CI jobs faster (#237)
  * Refactor options.sternConfig() (#236)
  * Return error when output option is invalid (#235)
  * Refactor template logic (#233)
  * Revert "add support to parse JSON logs (#228)" (#232)
  * Change the default of --container-state to `all` (#225)
  * Highlight matched strings in the log lines with the include
    option (#231)
  * Support resuming from the last log when retrying (#230)
  * add support to parse JSON logs (#228)
  * Show initContainers first when --no-follow and
  - -max-log-requests 1 (#226)
  * Add --max-log-requests flag to limit concurrent requests (#224)
  * Improve handling of container termination (#221)
  * Allow pods without labels to be selected in the resource query
    (#223)
  * Add `all` option to --container-state flag (#222)
* Mon Jan 30 2023 kastl@b1-systems.de
- Update to version 1.23.0:
  * Update CHANGELOG for v1.23.0 (#220)
  * Add @tksm to CODEOWNERS (#219)
  * Allow to specify --exclude-pod/container multiple times (#218)
  * Add --only-log-lines flag that prints only log lines (#216)
  * Fix typo of --verbosity flag (#215)
  * Add --verbosity flag to set log level verbosity (#214)
  * Add completion for flags with pre-defined choices (#211)
  * Fix bug where container-state is ignored when no-follow specified (#210)
  * Add dynamic completion for a resource query (#209)
  * Support <resource>/<name> form as a query (#208)
  * Fix indent in update-readme.go (#207)
  * Update dependencies and tools (#205)
  * Add --no-follow flag to exit when all logs have been shown (#204)
  * Use StringArrayVarP for --include and --exclude flags (#196)
  * Fix the invalid command in README.md (#193)
* Tue Sep 27 2022 kastl@b1-systems.de
- Update to version 1.22.0:
  * Update dependencies (#192)
  * Use Go 1.19 (#191)
  * added output modes to colorize json output (#190)
  * Update dependencies (#183)
  * Use Go 1.18 (#182)
  * Continue tailing logs even if timezone update fails (#178)
- BuildRequire go1.19
* Fri Mar  4 2022 Johannes Kastl <kastl@b1-systems.de>
- new package stern: Multi pod and container log tailing for Kubernetes
- using the fork at https://github.com/stern/stern that is maintained
